{
----------------------------------------------------------
MAS-CompMaker was used to generate this code
MAS-CompMaker, copyright(c) 2000, Mats Asplund / MAs Prod.
----------------------------------------------------------

Component Name: TmLED
        Author: Mats Asplund
      Creation: 2001-01-05
       Version: 1.0
   Description: A LED-imitation component. Four colors/three sizes
        Credit:
        E-mail: masprod@telia.com
          Site: http://w1.545.telia.com/~u54503556 or http://go.to/mdp
  Legal issues: Copyright (C) 2001 by Mats Asplund


         Usage: This software is provided 'as-is', without any express or
                implied warranty.  In no event will the author be held liable
                for any  damages arising from the use of this software.

                Permission is granted to anyone to use this software for any
                purpose, including commercial applications, and to alter it
                and redistribute it freely, subject to the following
                restrictions:

                1. The origin of this software must not be misrepresented,
                   you must not claim that you wrote the original software.
                   If you use this software in a product, an acknowledgment
                   in the product documentation would be appreciated but is
                   not required.

                2. Altered source versions must be plainly marked as such, and
                   must not be misrepresented as being the original software.

                3. This notice may not be removed or altered from any source
                   distribution.

                4. If you decide to use this software in any of your applications.
                   Send me an EMail and tell me about it.

Quick Reference:
                TmLED inherits from TImage.

                Key-Properties:

                  Size:  Sets the LED-size. Three sizes avaliable: small, normal
                         and big.

                  Color: Sets the LED-color. Four colors avaliable: red, yellow,
                         green and blue.

                  State: Puts the LED in ON- or OFF-state.

--------------------------------------------------------------------------------
}
unit mLED;

interface

uses
  SysUtils, WinTypes, WinProcs, Messages, Classes, Graphics, Controls,
  Forms, Dialogs, StdCtrls, ExtCtrls;

type
  TLEDColor = (lcYellow, lcRed, lcGreen, lcBlue);

  TLEDState = (lsON, lsOFF);

  TLEDSize  = (lzSmall, lzNormal, lzBig);

  TmLED = class(TImage)
private
  fCopyright: string;
  fColor: TLEDColor;
  fState: TLEDState;
  fSize: TLEDSize;
  procedure SetCop(Value: string);
  procedure SetColor(const Value: TLEDColor);
  procedure SetState(const Value: TLEDState);
  procedure SetSize(const Value: TLEDSize);
  procedure DrawLED(Size: TLEDSize; Color: TLEDColor; State: TLEDState);
  { Private declarations }
public
  constructor Create(AOwner: TComponent); override;
  destructor Destroy; override;
  { Private declarations }
published
  property Size: TLEDSize read fSize write SetSize;
  property State: TLEDState read fState write SetState;
  property Color: TLEDColor read fColor write SetColor;
  property Copyright: string read fCopyright write SetCop;
  { Published declarations }
end;


procedure Register;

implementation
{$R *.RES}

const
  ResNormal: array[1..8] of PChar =
  ('YOFF', 'YON', 'ROFF', 'RON', 'GOFF', 'GON', 'BOFF', 'BON');

  ResBig:    array[1..8] of PChar =
  ('YOFFB', 'YONB', 'ROFFB', 'RONB', 'GOFFB', 'GONB', 'BOFFB', 'BONB');

  ResSmall:  array[1..8] of PChar =
  ('YOFFS', 'YONS', 'ROFFS', 'RONS', 'GOFFS', 'GONS', 'BOFFS', 'BONS');

constructor TmLED.Create(AOwner: TComponent);
begin
  inherited Create(AOwner);
  AutoSize:= true;
  Visible:= true;
  Transparent:= true;
  fSize:= lzNormal;
  fColor:= lcRed;
  fState:= lsOff;
  DrawLED(fSize, fColor, fState);
  FCopyright:='Copyright (c) 2000, MAs Prod. / Mats Asplund';
end;

destructor TmLED.Destroy;
begin
  inherited Destroy;
end;

procedure TmLED.DrawLED(Size: TLEDSize; Color: TLEDColor; State: TLEDState);
var Pos: integer;
begin
  Pos:= 1;
  case fColor of
    lcYellow: if fState = lsOn then Pos:= 2 else Pos:= 1;
    lcRed:    if fState = lsOn then Pos:= 4 else Pos:= 3;
    lcGreen:  if fState = lsOn then Pos:= 6 else Pos:= 5;
    lcBlue:   if fState = lsOn then Pos:= 8 else Pos:= 7;
  end;
  case fSize of
    lzSmall:  Picture.Bitmap.Handle:= LoadBitmap(HInstance, ResSmall[Pos]);
    lzNormal: Picture.Bitmap.Handle:= LoadBitmap(HInstance, ResNormal[Pos]);
    lzBig:    Picture.Bitmap.Handle:= LoadBitmap(HInstance, ResBig[Pos]);
  end;
  Invalidate;
end;

procedure TmLED.SetSize(const Value: TLEDSize);
begin
  fSize := Value;
  DrawLED(fSize, fColor, fState);
end;

procedure TmLED.SetColor(const Value: TLEDColor);
begin
  fColor := Value;
  DrawLED(fSize, fColor, fState);
end;

procedure TmLED.SetState(const Value: TLEDState);
begin
  fState := Value;
  DrawLED(fSize, fColor, fState);
end;

procedure TmLED.SetCop(Value: string);
begin
  Exit;
end;

procedure Register;
begin
  RegisterComponents('MAs Prod.', [TmLED]);
end;

end.
